setwd("~/Desktop")

cf <- read.csv("QJPS_Barber_Butler_Preece_Replication_Data_Figure1.csv")

lower <- cf[cf$seat == "state:lower" | cf$seat == "state:upper",]

#differences by gender (all lower and upper house candidates and incumbents)
amt.female <- tapply(lower$total.receipts[lower$cand.gender == "F"], lower$cycle[lower$cand.gender == "F"], function(x) mean(x, na.rm = T))

amt.male <- tapply(lower$total.receipts[lower$cand.gender == "M"], lower$cycle[lower$cand.gender == "M"], function(x) mean(x, na.rm = T))

cycle <- unique(lower$cycle)

cpi <- rev(c(.95, 1, 1.01, 1.08, 1.15, 1.21, 1.27, 1.34, 1.39, 1.47, 1.55, 1.67))

amt.female.cpi <- amt.female*cpi
amt.male.cpi <- amt.male*cpi

dev.new(height = 4, width = 8)
par(mar = c(4, 5, 4, 2))
plot(cycle, amt.female.cpi, pch = 16, col = "pink", ylim = c(0, 102000), axes = F, ylab = "Average Fundraising \n (in $1,000, Inflation Adjusted)", xlab = "Election Cycle", main = "Gender Differences in Fundraising \n All State Legislative Candidates")
lines(cycle, amt.female.cpi, col = "pink")
points(cycle, amt.male.cpi, pch = 15, col = "blue")
lines(cycle, amt.male.cpi, lty = 2, col = "blue")
axis(1, seq(1990, 2012, 2))
axis(2, seq(0, 100000, 20000), labels = c("0", "20", "40", "60", "80", "100"), las = 2)
text(2000, 100000, "Male Candidates")
text(2000, 55000, "Female Candidates")
box()

##############################
##############################
##############################

data <- read.csv("QJPS_Barber_Butler_Preece_Replication_Data.csv")

##############################
#Model 1 of Table 1 - Money raised by winning candidate in next election cycle
##############################

summary(model1 <-lm(log.total.raised.candidate ~ male.winner + running.variable* male.winner, data = subset(data, running.variable >= -2 & running.variable <= 2 & female.margin != 50)))
length(model1$resid)

#####################################################
#Model 2 of Table 1 - Individual Contributions
#####################################################

summary(model2 <-lm(log.individual.money ~ male.winner + running.variable* male.winner, data=subset(data, running.variable >= -2 & running.variable <= 2 & female.margin != 50)))
length(model2$resid)

#####################################################
#Model 3 of Table 1 - PAC Contributions
#####################################################

summary(model3 <-lm(log.pac.money ~ male.winner + running.variable* male.winner, data=subset(data, running.variable >= -2 & running.variable <= 2 & female.margin != 50)))
length(model3$resid)

#####################################################
#Model 4 of Table 1 - Party
#####################################################

summary(model4 <-lm(log.party.money ~ male.winner + running.variable* male.winner, data=subset(data, running.variable >= -2 & running.variable <= 2 & female.margin != 50)))
length(model4$resid)

#####################################################
#Model 5 of Table 1 - Total money raised from male donors
#####################################################

summary(model5 <-lm(log.male.money ~ male.winner + running.variable* male.winner, data = subset(data, running.variable >= -2 & running.variable <= 2 & female.margin != 50)))
length(model5$resid)

#####################################################
#Model 6 of Table 1 - Total money raised from female donors
#####################################################

summary(model6 <-lm(log.female.money ~ male.winner + running.variable* male.winner, data=subset(data, running.variable >= -2 & running.variable <= 2 & female.margin != 50)))
length(model6$resid)


############################################################################################


################################
#Model 1 of Table 2 - Total contributions
################################

summary(model1b <-lm(log.total.raised.candidate ~ as.factor(cycle) + democrat + prev.elect + cfscore*democrat + total.votes + professional + pct.female.chamber + gop.gov + house + state.pres.dem + num.cands + running.variable*male.winner + male.winner, data = subset(data, running.variable >= -2.5 & running.variable <= 2.5 & female.margin != 50)))
length(model1b$resid)

################################
#Model 2 of Table 2 - Individual Contributions
################################

summary(model2b <-lm(log.individual.money ~ as.factor(cycle) + democrat + prev.elect + cfscore*democrat + total.votes + professional + pct.female.chamber + gop.gov + house + state.pres.dem + num.cands + running.variable*male.winner + male.winner, data = subset(data, running.variable >= -2.5 & running.variable <= 2.5 & female.margin != 50)))
length(model2b$resid)

################################
#Model 3 of Table 2 - PAC Contributions
################################

summary(model3b <-lm(log.pac.money ~ as.factor(cycle) + democrat + prev.elect + cfscore*democrat + total.votes + professional + pct.female.chamber + gop.gov + house + state.pres.dem + num.cands + running.variable*male.winner + male.winner, data = subset(data, running.variable >= -2.5 & running.variable <= 2.5 & female.margin != 50)))
length(model3b$resid)

################################
#Model 4 of Table 2 - Party Contributions
################################

summary(model4b <-lm(log.party.money ~ as.factor(cycle) + democrat + prev.elect + cfscore*democrat + total.votes + professional + pct.female.chamber + gop.gov + house + state.pres.dem + num.cands + running.variable*male.winner + male.winner, data = subset(data, running.variable >= -2.5 & running.variable <= 2.5 & female.margin != 50)))
length(model4b$resid)

#####################################################
#Model 5 of Table 2 - Male Individual Donors
#####################################################

summary(model5b <-lm(log.male.money ~ as.factor(cycle) + democrat + prev.elect + cfscore*democrat + total.votes + professional + pct.female.chamber + gop.gov + house + state.pres.dem + num.cands + running.variable*male.winner + male.winner, data = subset(data, running.variable >= -2.5 & running.variable <= 2.5 & female.margin != 50)))
length(model5b$resid)

#####################################################
#Model 6 of Table 2 - Female Individual Donors
#####################################################

summary(model6b <-lm(log.female.money ~ as.factor(cycle) + democrat + prev.elect + cfscore*democrat + total.votes + professional + pct.female.chamber + gop.gov + house + state.pres.dem + num.cands + running.variable*male.winner + male.winner, data = subset(data, running.variable >= -2.5 & running.variable <= 2.5 & female.margin != 50)))
length(model6b$resid)


############################################################################################


#####################################################
#Model 1 of Table 3 - Share of district's contributions
#####################################################

summary(model11 <-lm(share.district.total ~ male.winner + running.variable* male.winner, data=subset(data, running.variable >= -2 & running.variable <= 2 & female.margin != 50)))
length(model11$resid)

#####################################################
#Model 2 of Table 3 - Total contributions raised in district
#####################################################

summary(model12 <-lm(log.district.total ~ male.winner + running.variable* male.winner, data=subset(data, running.variable >= -2 & running.variable <= 2 & female.margin != 50)))
length(model12$resid)


############################################################################################


##############################
#Figure 2 - Money raised by winning candidate in next election cycle
##############################

#make the light points
#female.pctile = percentage of vote going to female candidate in the district
percentile <- tapply(data$total.raised.candidate, data$female.pctile, function(x) mean(x, na.rm = T))
summary(percentile)
percentile <- percentile[!is.na(percentile)]
percentile <- percentile[names(percentile) != "NaN"]

#only take observations near the 50% cutpoint of the forcing variable
percentile <- percentile[as.numeric(names(percentile)) >= 40 & as.numeric(names(percentile)) <= 60 & as.numeric(names(percentile)) != 50]

#x-axis of the plot
xaxis <- as.numeric(names(percentile))
quantile(percentile, .99)
quantile(percentile, .95)
quantile(percentile, .90)
quantile(percentile, .01)

dev.new(width = 6, height = 6)
par(mar = c(4, 5, 4, 2))
plot(xaxis, percentile, pch = 16, xlim = c(40, 60), ylim = c(6, 300000), ylab = "Money Raised by Winner in Election t+1 \n (in $1,000)", xlab = "Female Candidate's Vote Share in Election t", col = "black", main = "Total Contributions", cex = .5, axes = F)

abline(v = 50, lty = 2)
lines(lowess(xaxis[xaxis < 50], (percentile[as.numeric(names(percentile)) < 50])), lwd = 3.5)
lines(lowess(xaxis[xaxis > 50], (percentile[as.numeric(names(percentile)) > 50])), lwd = 3.5)
text(53, -2000, "Female Winners")
text(47.5, -2000, "Male Winners")
# axis(2, at = seq(7, 13, 2), labels = c("1", "8", "60", "442"), las = 2)
axis(2, at = seq(0, 300000, 100000), labels = c("0", "100", "200", "300"), las = 2)
axis(1, at = seq(40, 60, 5))
box()


#####################################################
#Figure 3a - Total money raised from male donors
#####################################################

#make the light points
percentile <- tapply(data$male.money, data$female.pctile, function(x) mean(x, na.rm = T))
summary(percentile)
percentile <- percentile[percentile >= 0]
percentile <- percentile[!is.na(percentile)]
percentile <- percentile[names(percentile) != "NaN"]

#only take observations near the 50% cutpoint of the forcing variable
percentile <- percentile[as.numeric(names(percentile)) >= 40 & as.numeric(names(percentile)) <= 60 & as.numeric(names(percentile)) != 50]

xaxis <- as.numeric(names(percentile))
quantile(percentile, .99)
quantile(percentile, .95)
quantile(percentile, .98)
quantile(percentile, .05)

dev.new(width = 6, height = 6)
par(mar = c(4, 5, 4, 2))
plot(xaxis, percentile, pch = 16, xlim = c(40, 60), ylim = c(0, 50000), ylab = "Money Raised by Winner in Election t+1 \n (in $1000)", xlab = "Female Candidate's Vote Share in Election t", col = "black", main = "Money Raised from Men", cex = .5, axes = F)

abline(v = 50, lty = 2)
lines(lowess(xaxis[xaxis < 50], (percentile[as.numeric(names(percentile)) < 50])), lwd = 3.5)
lines(lowess(xaxis[xaxis > 50], (percentile[as.numeric(names(percentile)) > 50])), lwd = 3.5)
text(53, -1000, "Female Winners")
text(47.5, -1000, "Male Winners")
axis(2, at = seq(0, 50000, 15000), labels = seq(0, 50, 15), las = 2)
axis(1, at = seq(40, 60, 5))
box()

#####################################################
#Figure 3b - TOTAL MONEY RAISED FROM WOMEN
#####################################################

#make the light points
percentile <- tapply(data$female.money, data$female.pctile, function(x) mean(x, na.rm = T))
summary(percentile)
percentile <- percentile[percentile >= 0]
percentile <- percentile[!is.na(percentile)]
percentile <- percentile[names(percentile) != "NaN"]

#only take observations near the 50% cutpoint of the forcing variable
percentile <- percentile[as.numeric(names(percentile)) >= 40 & as.numeric(names(percentile)) <= 60 & as.numeric(names(percentile)) != 50]

xaxis <- as.numeric(names(percentile))
quantile(percentile, .99)
quantile(percentile, .95)
quantile(percentile, .90)
quantile(percentile, .05)

dev.new(width = 6, height = 6)
par(mar = c(4, 5, 4, 2))
plot(xaxis, percentile, pch = 16, xlim = c(40, 60), ylim = c(0, 50000), ylab = "Money Raised by Winner in Election t+1 \n (in $1000)", xlab = "Female Candidate's Vote Share in Election t", col = "black", main = "Money Raised from Women", cex = .5, axes = F)

abline(v = 50, lty = 2)
lines(lowess(xaxis[xaxis < 50], (percentile[as.numeric(names(percentile)) < 50])), lwd = 3.5)
lines(lowess(xaxis[xaxis > 50], (percentile[as.numeric(names(percentile)) > 50])), lwd = 3.5)
text(53, -100, "Female Winners")
text(47.5, -100, "Male Winners")
axis(2, at = seq(0, 50000, 15000), labels = seq(0, 50, 15), las = 2)
#axis(2, at = seq(7, 13, 2), labels = c("1", "8", "60", "442"), las = 2)
axis(1, at = seq(40, 60, 5))
box()

#####################################################
#Figure 4a - Share of district's total contributions
#####################################################

#make the light points
percentile <- tapply(data$share.district.total, data$female.pctile, function(x) mean(x, na.rm = T))
summary(percentile)
percentile <- percentile[percentile >= 0]
percentile <- percentile[!is.na(percentile)]
percentile <- percentile[names(percentile) != "NaN"]

#only take observations near the 50% cutpoint of the forcing variable
percentile <- percentile[as.numeric(names(percentile)) >= 40 & as.numeric(names(percentile)) <= 60 & as.numeric(names(percentile)) != 50]

xaxis <- as.numeric(names(percentile))
quantile(percentile, .99)
quantile(percentile, .95)
quantile(percentile, .90)
quantile(percentile, .05)

dev.new(width = 6, height = 6)
par(mar = c(4, 5, 4, 2))
plot(xaxis, percentile, pch = 16, xlim = c(40, 60), ylim = c(0, 1), ylab = "Share of District's Contributions in Election t + 1 \n Going to Winner", xlab = "Female Candidate's Vote Share in Election t", col = "black", main = "Share of District's Total Contributions", cex = .5)

abline(v = 50, lty = 2)
lines(lowess(xaxis[xaxis < 50], (percentile[as.numeric(names(percentile)) < 50])), lwd = 3.5)
lines(lowess(xaxis[xaxis > 50], (percentile[as.numeric(names(percentile)) > 50])), lwd = 3.5)
text(53, 0, "Female Winner")
text(47.5, 0, "Male Winner")

#####################################################
#Figure 4b - TOTAL MONEY RAISED IN THE DISTRICT
#####################################################

#make the light points
percentile <- tapply(data$log.district.total, data$female.pctile, function(x) mean(x, na.rm = T))
summary(percentile)
percentile <- percentile[percentile >= 0]
percentile <- percentile[!is.na(percentile)]
percentile <- percentile[names(percentile) != "NaN"]

#only take observations near the 50% cutpoint of the forcing variable
percentile <- percentile[as.numeric(names(percentile)) >= 40 & as.numeric(names(percentile)) <= 60 & as.numeric(names(percentile)) != 50]

xaxis <- as.numeric(names(percentile))
quantile(percentile, .99)
quantile(percentile, .95)
quantile(percentile, .90)
quantile(percentile, .05)

dev.new(width = 6, height = 6)
par(mar = c(4, 5, 4, 2))
plot(xaxis, percentile, pch = 16, xlim = c(40, 60), ylim = c(9, 13), ylab = "Total Money Raised by All Candidates in District in Election t+1\n(Logged Scale, in $1000)", xlab = "Female Candidate's Vote Share in Election t", col = "black", main = "Money Raised By All Candidates in District", cex = .5, axes = F)

abline(v = 50, lty = 2)
lines(lowess(xaxis[xaxis < 50], (percentile[as.numeric(names(percentile)) < 50])), lwd = 3.5)
lines(lowess(xaxis[xaxis > 50], (percentile[as.numeric(names(percentile)) > 50])), lwd = 3.5)
text(53, -2000, "Female Winners")
text(47.5, -2000, "Male Winners")
axis(2, at = seq(9, 13, 1), labels = c("8", "22", "60", "163", "442"), las = 2)
axis(1, at = seq(40, 60, 5))
box()

