setwd("~/Desktop")

##############################
#Figure 1 - supplemental materials
##############################

cf <- read.csv("QJPS_Barber_Butler_Preece_Replication_Data_Figure1.csv")

lower <- cf[cf$seat == "state:lower" | cf$seat == "state:upper",]

#Incumbents
amt.female <- tapply(lower$total.receipts[lower$cand.gender == "F" & lower$Incum.Chall == "I"], lower$cycle[lower$cand.gender == "F"  & lower$Incum.Chall == "I"], function(x) mean(x, na.rm = T))

amt.male <- tapply(lower$total.receipts[lower$cand.gender == "M" & lower$Incum.Chall == "I"], lower$cycle[lower$cand.gender == "M" & lower$Incum.Chall == "I"], function(x) mean(x, na.rm = T))

cycle <- unique(lower$cycle)

cpi <- rev(c(.95, 1, 1.01, 1.08, 1.15, 1.21, 1.27, 1.34, 1.39, 1.47, 1.55, 1.67))

amt.female.cpi <- amt.female*cpi
amt.male.cpi <- amt.male*cpi

dev.new(height = 4, width = 8)
par(mar = c(4, 5, 4, 2))
plot(cycle, amt.female.cpi, pch = 16, col = "pink", ylim = c(0, 130000), axes = F, ylab = "Average Fundraising \n (in $1,000)", xlab = "Election Cycle", main = "Gender Differences in Fundraising \n Incumbent State Legislators")
lines(cycle, amt.female.cpi, col = "pink")
points(cycle, amt.male.cpi, pch = 15, col = "blue")
lines(cycle, amt.male.cpi, lty = 2, col = "blue")
axis(1, seq(1990, 2012, 2))
axis(2, seq(0, 150000, 30000), labels = c("0", "30", "60", "90", "120", "150"), las = 2)
text(2000, 126000, "Male Incumbents")
text(2000, 50000, "Female Incumbents")
box()


##############################
##############################
##############################


data <- read.csv("QJPS_Barber_Butler_Preece_Replication_Data.csv")

##############################
### Full Distribution and logged data
##############################

#make the light points
percentile <- tapply(data$log.total.raised.candidate, data$female.pctile, function(x) mean(x, na.rm = T))
summary(percentile)
percentile <- percentile[percentile >= 0]
percentile <- percentile[!is.na(percentile)]
percentile <- percentile[names(percentile) != "NaN"]

#only take observations near the 50% cutpoint of the forcing variable
percentile <- percentile[as.numeric(names(percentile)) >= 40 & as.numeric(names(percentile)) <= 60 & as.numeric(names(percentile)) != 50]

xaxis <- as.numeric(names(percentile))

dev.new(width = 6, height = 6)
par(mar = c(4, 5, 4, 2))
plot(data$female.pctile, data$log.total.raised.candidate, pch = 16, ylim = c(3.7, 15), xlim = c(40, 60), ylab = "Money Raised by Winner in Election t+1 \n (Logged $)", xlab = "Female Candidate's Vote Share in Election t", col = "#00000090", main = "Total Contributions", cex = .5, axes = F)

abline(v = 50, lty = 2)
# points(xaxis2, percentile2, pch = 16, col = "black")
lines(lowess(xaxis[xaxis < 50], (percentile[as.numeric(names(percentile)) < 50])), lwd = 3.5)
lines(lowess(xaxis[xaxis > 50], (percentile[as.numeric(names(percentile)) > 50])), lwd = 3.5)
text(53, 4, "Female Winners")
text(47.5, 4, "Male Winners")
# axis(2, at = seq(7, 13, 2), labels = c("1", "8", "60", "442"), las = 2)
axis(2, at = seq(0, 16, 2), las = 2)
axis(1, at = seq(40, 60, 5))
box()

##############################
#PAC Contributions
##############################

#make the light points
percentile <- tapply(data$pac.money, data$female.pctile, function(x) mean(x, na.rm = T))
summary(percentile)
percentile <- percentile[percentile >= 0]
percentile <- percentile[!is.na(percentile)]
percentile <- percentile[names(percentile) != "NaN"]

#only take observations near the 50% cutpoint of the forcing variable
percentile <- percentile[as.numeric(names(percentile)) >= 40 & as.numeric(names(percentile)) <= 60 & as.numeric(names(percentile)) != 50]

xaxis <- as.numeric(names(percentile))

quantile(percentile, .99)
quantile(percentile, .95)
quantile(percentile, .90)

dev.new()
par(mar = c(4, 5, 4, 2))
plot(xaxis, percentile, pch = 16, xlim = c(40, 60), ylim = c(0, 200000), ylab = "Money Raised by Winner in Election t+1 \n (Logged Scale, in $1000)", xlab = "Female Candidate's Vote Share in Election t", col = "black", main = "PAC Contributions", cex = .5, axes = F)

abline(v = 50, lty = 2)
# points(xaxis2, percentile2, pch = 16, col = "black")
lines(lowess(xaxis[xaxis < 50], (percentile[as.numeric(names(percentile)) < 50])), lwd = 3.5)
lines(lowess(xaxis[xaxis > 50], (percentile[as.numeric(names(percentile)) > 50])), lwd = 3.5)
text(53, -2000, "Female Winners")
text(47.5, -2000, "Male Winners")
# axis(2, at = seq(0, 200000, 40000), labels = seq(0, 200, 40), las = 2)
axis(2, at = seq(0, 300000, 50000), labels = c("0", "50", "100", "150", "200", "250", "300"), las = 2)
axis(1, at = seq(40, 60, 5))
box()

##############################
#Party Contributions
##############################

#make the light points
percentile <- tapply(data$party.money, data$female.pctile, function(x) mean(x, na.rm = T))
summary(percentile)
percentile <- percentile[percentile >= 0]
percentile <- percentile[!is.na(percentile)]
percentile <- percentile[names(percentile) != "NaN"]

#only take observations near the 50% cutpoint of the forcing variable
percentile <- percentile[as.numeric(names(percentile)) >= 40 & as.numeric(names(percentile)) <= 60 & as.numeric(names(percentile)) != 50]

xaxis <- as.numeric(names(percentile))

quantile(percentile, .99)
quantile(percentile, .95)
quantile(percentile, .90)

dev.new()
par(mar = c(4, 5, 4, 2))
plot(xaxis, percentile, pch = 16, xlim = c(40, 60), ylim = c(0, 200000), ylab = "Money Raised by Winner in Election t+1 \n (Logged Scale, in $1000)", xlab = "Female Candidate's Vote Share in Election t", col = "black", main = "Party Organization Contributions", cex = .5, axes = F)

abline(v = 50, lty = 2)
# points(xaxis2, percentile2, pch = 16, col = "black")
lines(lowess(xaxis[xaxis < 50], (percentile[as.numeric(names(percentile)) < 50])), lwd = 3.5)
lines(lowess(xaxis[xaxis > 50], (percentile[as.numeric(names(percentile)) > 50])), lwd = 3.5)
text(53, -2000, "Female Winners")
text(47.5, -2000, "Male Winners")
# axis(2, at = seq(0, 200000, 40000), labels = seq(0, 200, 40), las = 2)
axis(2, at = seq(0, 300000, 50000), labels = c("0", "50", "100", "150", "200", "250", "300"), las = 2)
axis(1, at = seq(40, 60, 5))
box()


#####################################################
#Probability of Winning Next Election
#####################################################

#make the light points
percentile <- tapply(data$won.again, data$female.pctile, function(x) mean(x, na.rm = T))
summary(percentile)
percentile <- percentile[percentile >= 0]
percentile <- percentile[!is.na(percentile)]
percentile <- percentile[names(percentile) != "NaN"]

#only take observations near the 50% cutpoint of the forcing variable
percentile <- percentile[as.numeric(names(percentile)) >= 40 & as.numeric(names(percentile)) <= 60 & as.numeric(names(percentile)) != 50]

xaxis <- as.numeric(names(percentile))

quantile(percentile, .99)
quantile(percentile, .95)
quantile(percentile, .90)

dev.new()
par(mar = c(4, 5, 4, 2))
plot(xaxis, percentile, pch = 16, xlim = c(40, 60), ylim = c(0, 1), ylab = "Probability of Winning \n in Election t + 1", xlab = "Female Candidate's Vote Share in Election t", col = "black", main = "Probability of Winning Next Election", cex = .5)
abline(v = 50, lty = 2)
lines(lowess(xaxis[xaxis < 50], (percentile[as.numeric(names(percentile)) < 50])), lwd = 3.5)
lines(lowess(xaxis[xaxis > 50], (percentile[as.numeric(names(percentile)) > 50])), lwd = 3.5)
text(53, 0, "Female Winner")
text(47.5, 0, "Male Winner")



#####################################################
#Balance Test 1 - Probability of a female candidate in the prior election
#####################################################

#make the light points
percentile <- tapply(data$female.cand.last, data$female.pctile, function(x) mean(x, na.rm = T))
summary(percentile)
percentile <- percentile[percentile >= 0]
percentile <- percentile[!is.na(percentile)]
percentile <- percentile[names(percentile) != "NaN"]

#only take observations near the 50% cutpoint of the forcing variable
percentile <- percentile[as.numeric(names(percentile)) >= 30 & as.numeric(names(percentile)) <= 70 & as.numeric(names(percentile)) != 50]

xaxis <- as.numeric(names(percentile))

quantile(percentile, .99)
quantile(percentile, .95)
quantile(percentile, .90)
quantile(percentile, .01)

dev.new()
par(mar = c(4, 5, 4, 2))
plot(xaxis, percentile, pch = 16, xlim = c(30, 70), ylim = c(0, 1), ylab = "Probability that a Female Candidate \n Ran in Election t-1", xlab = "Female Candidate's Vote Share in Election t", col = "black", main = "Testing For Sorting: Prior Female Candidates", cex = .5, axes = F)

abline(v = 50, lty = 2)
lines(lowess(xaxis[xaxis < 50], (percentile[as.numeric(names(percentile)) < 50])), lwd = 3.5)
lines(lowess(xaxis[xaxis > 50], (percentile[as.numeric(names(percentile)) > 50])), lwd = 3.5)
text(55.5, .95, "Female Winners")
text(45, .95, "Male Winners")
axis(2, at = seq(0, 1, .2), las = 2)
axis(1, at = seq(30, 70, 10))
box()

#####################################################
#Balance Test 2 - Total raised in district in t-1
#####################################################

data$log.total.dist.last <- log(data$total.dist.last)

#make the light points
percentile <- tapply(data$log.total.dist.last, data$female.pctile, function(x) mean(x, na.rm = T))
summary(percentile)
percentile <- percentile[percentile >= 0]
percentile <- percentile[!is.na(percentile)]
percentile <- percentile[names(percentile) != "NaN"]

#only take observations near the 50% cutpoint of the forcing variable
percentile <- percentile[as.numeric(names(percentile)) >= 30 & as.numeric(names(percentile)) <= 70 & as.numeric(names(percentile)) != 50]

xaxis <- as.numeric(names(percentile))

quantile(percentile, .99)
quantile(percentile, .95)
quantile(percentile, .90)
quantile(percentile, .01)

dev.new()
par(mar = c(4, 5, 4, 2))
plot(xaxis, percentile, pch = 16, xlim = c(30, 70), ylim = c(0, 14), ylab = "Total District Spending (Logged) \n in Election t-1", xlab = "Female Candidate's Vote Share in Election t", col = "black", main = "Testing For Sorting: Prior Spending in District", cex = .5, axes = F)

abline(v = 50, lty = 2)
lines(lowess(xaxis[xaxis < 50], (percentile[as.numeric(names(percentile)) < 50])), lwd = 3.5)
lines(lowess(xaxis[xaxis > 50], (percentile[as.numeric(names(percentile)) > 50])), lwd = 3.5)
text(56, .85, "Female Winners")
text(45, .85, "Male Winners")
axis(2, at = seq(0, 14, 3), labels = c("$0", "$20", "$400", "$8000", "$163,000"), las = 2)
axis(1, at = seq(30, 70, 10))
box()


#####################################################
#Balance Test 3 - Percent Democratic vote share in election t
#####################################################

#make the light points
percentile <- tapply(data$pct.dem.last, data$female.pctile, function(x) mean(x, na.rm = T))
summary(percentile)
percentile <- percentile[percentile >= 0]
percentile <- percentile[!is.na(percentile)]
percentile <- percentile[names(percentile) != "NaN"]

#only take observations near the 50% cutpoint of the forcing variable
percentile <- percentile[as.numeric(names(percentile)) >= 30 & as.numeric(names(percentile)) <= 70 & as.numeric(names(percentile)) != 50]

xaxis <- as.numeric(names(percentile))

quantile(percentile, .99)
quantile(percentile, .95)
quantile(percentile, .90)
quantile(percentile, .01)

dev.new()
par(mar = c(4, 5, 4, 2))
plot(xaxis, percentile, pch = 16, xlim = c(30, 70), ylim = c(0, 100), ylab = "Democratic Vote Share \n in Election t-1", xlab = "Female Candidate's Vote Share in Election t", col = "black", main = "Testing For Sorting: Prior Democratic Vote Share", cex = .5, axes = F)

abline(v = 50, lty = 2)
lines(lowess(xaxis[xaxis < 50], (percentile[as.numeric(names(percentile)) < 50])), lwd = 3.5)
lines(lowess(xaxis[xaxis > 50], (percentile[as.numeric(names(percentile)) > 50])), lwd = 3.5)
text(56, 85, "Female Winners")
text(45, 85, "Male Winners")
axis(2, at = seq(0, 100, 20), las = 2)
axis(1, at = seq(30, 70, 10))
box()

#####################################################
#Balance Test 4 - Probability female candidate is incumbent in election t
#####################################################

#make the light points
percentile <- tapply(data$female.inc, data$female.pctile, function(x) mean(x, na.rm = T))
summary(percentile)
percentile <- percentile[percentile >= 0]
percentile <- percentile[!is.na(percentile)]
percentile <- percentile[names(percentile) != "NaN"]

#only take observations near the 50% cutpoint of the forcing variable
percentile <- percentile[as.numeric(names(percentile)) >= 30 & as.numeric(names(percentile)) <= 70 & as.numeric(names(percentile)) != 50]

xaxis <- as.numeric(names(percentile))

quantile(percentile, .99)
quantile(percentile, .95)
quantile(percentile, .90)
quantile(percentile, .01)

dev.new()
par(mar = c(4, 5, 4, 2))
plot(xaxis, percentile, pch = 16, xlim = c(30, 70), ylim = c(0, 1), ylab = "Probability that the Female Candidate \n is the Incumbent in Election t", xlab = "Female Candidate's Vote Share in Election t", col = "black", main = "Testing For Sorting: Prior Incumbency", cex = .5, axes = F)

abline(v = 50, lty = 2)
lines(lowess(xaxis[xaxis < 50], (percentile[as.numeric(names(percentile)) < 50])), lwd = 3.5)
lines(lowess(xaxis[xaxis > 50], (percentile[as.numeric(names(percentile)) > 50])), lwd = 3.5)
text(55.5, .85, "Female Winners")
text(45, .85, "Male Winners")
axis(2, at = seq(0, 1, .2), las = 2)
axis(1, at = seq(30, 70, 10))
box()



#####################################################
#Balance Test 5 - Did female candidate have prior elected experience
#####################################################
#make the light points
percentile <- tapply(data$prev.elect, data$female.pctile, function(x) mean(x, na.rm = T))
summary(percentile)
percentile <- percentile[percentile >= 0]
percentile <- percentile[!is.na(percentile)]
percentile <- percentile[names(percentile) != "NaN"]

#only take observations near the 50% cutpoint of the forcing variable
percentile <- percentile[as.numeric(names(percentile)) >= 30 & as.numeric(names(percentile)) <= 70 & as.numeric(names(percentile)) != 50]

xaxis <- as.numeric(names(percentile))

quantile(percentile, .99)
quantile(percentile, .95)
quantile(percentile, .90)
quantile(percentile, .01)

dev.new()
par(mar = c(4, 5, 4, 2))
plot(xaxis, percentile, pch = 16, xlim = c(47.5, 52.5), ylim = c(0, 1), ylab = "Probability that the Winning Candidate \n has prior elected experience", xlab = "Female Candidate's Vote Share in Election t", col = "black", main = "Testing For Sorting: Prior Elected Experience", cex = .5, axes = F)

abline(v = 50, lty = 2)
lines(lowess(xaxis[xaxis < 50], (percentile[as.numeric(names(percentile)) < 50])), lwd = 3.5)
lines(lowess(xaxis[xaxis > 50], (percentile[as.numeric(names(percentile)) > 50])), lwd = 3.5)
text(55.5, .85, "Female Winners")
text(45, .85, "Male Winners")
axis(2, at = seq(0, 1, .2), las = 2)
axis(1, at = seq(47, 53, 1))
box()



#####################################################
## Varying Bandwidth - Total money raised
#####################################################
coefficients <- NULL
lower <- NULL
upper <- NULL

for (i in seq(.5, 10, .25)){

summary(total.raised <-lm(log.total.raised.candidate ~ male.winner + running.variable* male.winner, data=subset(data, data$running.variable >= -1*i & data$running.variable <= i & data$female.margin != 50)))

coef <- total.raised$coef[2]

coefficients <- c(coefficients, coef)
lower <- c(lower, coef - 1.64*sqrt(diag(vcov(total.raised))[2]))
upper <- c(upper, coef + 1.64*sqrt(diag(vcov(total.raised))[2]))
}

dev.new(width = 7, height = 4)
par(mar = c(5, 5, 4, 2))
plot(seq(.5, 10, .25), coefficients, pch = 16, cex = .5, ylim = c(-1, 2), xlab = "Size of Bandwidth Around Cutpoint", ylab = "Coefficient Estimate \n Male Versus Female Candidate Winning", main = "Log Total Money Raised \n Effect Size with Different Bandwiths", axes = F)
segments(x0 = seq(.5, 10, .25), x1 = seq(.5, 10, .25), y0 = lower, y1 = upper)
abline(h = 0, lty = 2, col = "grey")
axis(2, at = seq(-1, 2, .5), las = 2)
axis(1, at = seq(0, 10, 1), las = 1)
box()
arrows(x1 = 2, x0 = 2.8, y1 = 1.41, y0 = 1.85, length = .1)
text(2.7, 1.85, "Reported in Paper", cex = .7, pos = 4)




#####################################################
## Varying Bandwidth - Total individual money raised
#####################################################

coefficients <- NULL
lower <- NULL
upper <- NULL

for (i in seq(.5, 10, .25)){

summary(total.ind <-lm(log.individual.money ~ male.winner + running.variable* male.winner, data=subset(data, data$running.variable >= -1*i & data$running.variable <= i & data$female.margin != 50)))

coef <- total.ind$coef[2]

coefficients <- c(coefficients, coef)
lower <- c(lower, coef - 1.64*sqrt(diag(vcov(total.ind))[2]))
upper <- c(upper, coef + 1.64*sqrt(diag(vcov(total.ind))[2]))
}

dev.new(width = 7, height = 4)
par(mar = c(5, 5, 4, 2))
plot(seq(.5, 10, .25), coefficients, pch = 16, cex = .5, ylim = c(-1, 2), xlab = "Size of Bandwidth Around Cutpoint", ylab = "Coefficient Estimate \n Male Versus Female Candidate Winning", main = "Log Total Individual Money Raised \n Effect Size with Different Bandwiths", axes = F)
segments(x0 = seq(.5, 10, .25), x1 = seq(.5, 10, .25), y0 = lower, y1 = upper)
abline(h = 0, lty = 2, col = "grey")
axis(2, at = seq(-1, 2, .5), las = 2)
axis(1, at = seq(0, 10, 1), las = 1)
box()
arrows(x1 = 2.05, x0 = 2.8, y1 = 1.85, y0 = 1.85, length = .1)
text(2.7, 1.85, "Reported in Paper", cex = .7, pos = 4)



#####################################################
## Varying Bandwidth - Total PAC money raised
#####################################################

coefficients <- NULL
lower <- NULL
upper <- NULL

for (i in seq(.5, 10, .25)){

summary(total.pac <-lm(log.pac.money ~ male.winner + running.variable* male.winner, data=subset(data, data$running.variable >= -1*i & data$running.variable <= i & data$female.margin != 50)))

coef <- total.pac$coef[2]

coefficients <- c(coefficients, coef)
lower <- c(lower, coef - 1.64*sqrt(diag(vcov(total.pac))[2]))
upper <- c(upper, coef + 1.64*sqrt(diag(vcov(total.pac))[2]))
}


dev.new(width = 7, height = 4)
par(mar = c(5, 5, 4, 2))
plot(seq(.5, 10, .25), coefficients, pch = 16, cex = .5, ylim = c(-1, 2), xlab = "Size of Bandwidth Around Cutpoint", ylab = "Coefficient Estimate \n Male Versus Female Candidate Winning", main = "Log Total PAC Money Raised \n Effect Size with Different Bandwiths", axes = F)
segments(x0 = seq(.5, 10, .25), x1 = seq(.5, 10, .25), y0 = lower, y1 = upper)
abline(h = 0, lty = 2, col = "grey")
axis(2, at = seq(-1, 2, .5), las = 2)
axis(1, at = seq(0, 10, 1), las = 1)
box()
arrows(x1 = 2, x0 = 2.8, y1 = 1.4, y0 = 1.85, length = .1)
text(2.7, 1.85, "Reported in Paper", cex = .7, pos = 4)



#####################################################
## Varying Bandwidth - Total party money raised
#####################################################

coefficients <- NULL
lower <- NULL
upper <- NULL

for (i in seq(.5, 10, .25)){

summary(total.party <-lm(log.party.money ~ male.winner + running.variable* male.winner, data=subset(data, data$running.variable >= -1*i & data$running.variable <= i & data$female.margin != 50)))

coef <- total.party$coef[2]

coefficients <- c(coefficients, coef)
lower <- c(lower, coef - 1.64*sqrt(diag(vcov(total.party))[2]))
upper <- c(upper, coef + 1.64*sqrt(diag(vcov(total.party))[2]))
}

dev.new(width = 7, height = 4)
par(mar = c(5, 5, 4, 2))
plot(seq(.5, 10, .25), coefficients, pch = 16, cex = .5, ylim = c(-1, 2), xlab = "Size of Bandwidth Around Cutpoint", ylab = "Coefficient Estimate \n Male Versus Female Candidate Winning", main = "Log Total Party Money Raised \n Effect Size with Different Bandwiths", axes = F)
segments(x0 = seq(.5, 10, .25), x1 = seq(.5, 10, .25), y0 = lower, y1 = upper)
abline(h = 0, lty = 2, col = "grey")
axis(2, at = seq(-1, 2, .5), las = 2)
axis(1, at = seq(0, 10, 1), las = 1)
box()
arrows(x1 = 2, x0 = 2.8, y1 = 1.41, y0 = 1.85, length = .1)
text(2.7, 1.85, "Reported in Paper", cex = .7, pos = 4)



#####################################################
## Varying Bandwidth - Total male money raised
#####################################################

coefficients <- NULL
lower <- NULL
upper <- NULL

for (i in seq(.5, 10, .25)){

summary(total.men <-lm(log.male.money ~ male.winner + running.variable* male.winner, data=subset(data, data$running.variable >= -1*i & data$running.variable <= i & data$female.margin != 50)))

coef <- total.men$coef[2]

coefficients <- c(coefficients, coef)
lower <- c(lower, coef - 1.64*sqrt(diag(vcov(total.men))[2]))
upper <- c(upper, coef + 1.64*sqrt(diag(vcov(total.men))[2]))
}


dev.new(width = 7, height = 4)
par(mar = c(5, 5, 4, 2))
plot(seq(.5, 10, .25), coefficients, pch = 16, cex = .5, ylim = c(-1, 2), xlab = "Size of Bandwidth Around Cutpoint", ylab = "Coefficient Estimate \n Male Versus Female Candidate Winning", main = "Log Total Money Raised from Male Donors \n Effect Size with Different Bandwiths", axes = F)
segments(x0 = seq(.5, 10, .25), x1 = seq(.5, 10, .25), y0 = lower, y1 = upper)
abline(h = 0, lty = 2, col = "grey")
axis(2, at = seq(-1, 2, .5), las = 2)
axis(1, at = seq(0, 10, 1), las = 1)
box()
arrows(x1 = 2, x0 = 2.8, y1 = 1.35, y0 = 1.85, length = .1)
text(2.7, 1.85, "Reported in Paper", cex = .7, pos = 4)


#####################################################
## Varying Bandwidth - Total female money raised
#####################################################

coefficients <- NULL
lower <- NULL
upper <- NULL

for (i in seq(.5, 10, .25)){

summary(total.female <-lm(log.female.money ~ male.winner + running.variable* male.winner, data=subset(data, data$running.variable >= -1*i & data$running.variable <= i & data$female.margin != 50)))

coef <- total.female$coef[2]

coefficients <- c(coefficients, coef)
lower <- c(lower, coef - 1.64*sqrt(diag(vcov(total.female))[2]))
upper <- c(upper, coef + 1.64*sqrt(diag(vcov(total.female))[2]))
}

dev.new(width = 7, height = 4)
par(mar = c(5, 5, 4, 2))
plot(seq(.5, 10, .25), coefficients, pch = 16, cex = .5, ylim = c(-1, 2), xlab = "Size of Bandwidth Around Cutpoint", ylab = "Coefficient Estimate \n Male Versus Female Candidate Winning", main = "Log Total Money Raised from Female Donors \n Effect Size with Different Bandwiths", axes = F)
segments(x0 = seq(.5, 10, .25), x1 = seq(.5, 10, .25), y0 = lower, y1 = upper)
abline(h = 0, lty = 2, col = "grey")
axis(2, at = seq(-1, 2, .5), las = 2)
axis(1, at = seq(0, 10, 1), las = 1)
box()
arrows(x1 = 2, x0 = 2.8, y1 = .85, y0 = 1.85, length = .1)
text(2.7, 1.85, "Reported in Paper", cex = .7, pos = 4)




































































